Django-CheetahTemplate
======================

Use CheetahTemplate3 in Django.

Author: Oleg Broytman <phd@phdru.name>.

Copyright (C) 2018 PhiloSoft Design.

License: MIT.

| Home Page:     https://github.com/CheetahTemplate3/django-cheetahtemplate
| PyPI:          https://pypi.python.org/pypi/django-cheetahtemplate
